@@ -2,14 +2,13 @@ import logging
 from copy import deepcopy
 from pymongo.errors import OperationFailure
 
+from glasskit import ctx
 from glasskit.uorm.errors import DoNotSave
 from ..db import db
 from .fields import ObjectIdField
 from .meta import MetaModel
 from .hooks import BaseModelHook
 
-log = logging.getLogger("uorm")
-
 
 class BaseModel(MetaModel):
 
@@ -64,8 +63,11 @@ class BaseModel(MetaModel):
         if model_hook_class not in cls.__hooks_classes__:
             cls.__hooks_classes__.add(model_hook_class)
             model_hook_class.on_hook_register(cls, *args, **kwargs)
-            log.debug("Registered hook %s for model %s",
-                          model_hook_class.__name__, cls.__name__)
+            ctx.log.debug(
+                "Registered hook %s for model %s",
+                model_hook_class.__name__,
+                cls.__name__,
+            )
 
     @classmethod
     def unregister_model_hook(cls, model_hook_class):
@@ -124,8 +126,13 @@ class BaseModel(MetaModel):
             try:
                 hook.on_model_destroy(self)
             except Exception as e:
-                log.error("error executing destroy hook %s on model %s(%s): %s",
-                              hook.__class__.__name__, self.__class__.__name__, self._id, e)
+                ctx.log.error(
+                    "error executing destroy hook %s on model %s(%s): %s",
+                    hook.__class__.__name__,
+                    self.__class__.__name__,
+                    self._id,
+                    e,
+                )
         return self
 
     def save(self, skip_callback=False, invalidate_cache=True):
@@ -153,8 +160,13 @@ class BaseModel(MetaModel):
             try:
                 hook.on_model_save(self, is_new)
             except Exception as e:
-                log.error("error executing save hook %s on model %s(%s): %s",
-                              hook.__class__.__name__, self.__class__.__name__, self._id, e)
+                ctx.log.error(
+                    "error executing save hook %s on model %s(%s): %s",
+                    hook.__class__.__name__,
+                    self.__class__.__name__,
+                    self._id,
+                    e,
+                )
 
         self.__set_initial_state()
         if not skip_callback:
@@ -163,9 +175,8 @@ class BaseModel(MetaModel):
         return self
 
     def __repr__(self):
-        attributes = ["%s=%r" % (a, getattr(self, a))
-                      for a in self.__fields__]
-        return '%s(\n    %s\n)' % (self.__class__.__name__, ',\n    '.join(attributes))
+        attributes = ["%s=%r" % (a, getattr(self, a)) for a in self.__fields__]
+        return "%s(\n    %s\n)" % (self.__class__.__name__, ",\n    ".join(attributes))
 
     def __eq__(self, other):
         if self.__class__ != other.__class__:
@@ -186,17 +197,18 @@ class BaseModel(MetaModel):
     def to_dict(self, fields=None, include_restricted=False):
         if fields is None:
             fields = self.__fields__
-            result = {}
-            for field in fields:
-                if field in self.__restricted_fields__ and not include_restricted:
-                    continue
-                if not hasattr(self, field):
-                    continue
-                value = getattr(self, field)
-                if callable(value):
-                    continue
-                result[field] = value
-            return result
+
+        result = {}
+        for field in fields:
+            if field in self.__restricted_fields__ and not include_restricted:
+                continue
+            if not hasattr(self, field):
+                continue
+            value = getattr(self, field)
+            if callable(value):
+                continue
+            result[field] = value
+        return result
 
     @classmethod
     def create(cls, **attrs):
@@ -217,25 +229,28 @@ class BaseModel(MetaModel):
                 try:
                     db.conn[cls.collection].create_index(keys, **options)
                 except OperationFailure as e:
-                    if e.details.get("codeName") == "IndexOptionsConflict" or e.details.get("code") == 85:
+                    if (
+                        e.details.get("codeName") == "IndexOptionsConflict"
+                        or e.details.get("code") == 85
+                    ):
                         if overwrite:
                             if loud:
-                                log.debug(
-                                    "Dropping index %s as conflicting", keys)
+                                ctx.log.debug("Dropping index %s as conflicting", keys)
                             db.conn[cls.collection].drop_index(keys)
                             if loud:
-                                log.debug(
-                                    "Creating index with options: %s, %s", keys, options)
-                            db.conn[cls.collection].create_index(
-                                keys, **options)
+                                ctx.log.debug(
+                                    "Creating index with options: %s, %s", keys, options
+                                )
+                            db.conn[cls.collection].create_index(keys, **options)
                         else:
-                            log.error(
-                                "Index %s conflicts with an existing one, use overwrite param to fix it", keys
+                            ctx.log.error(
+                                "Index %s conflicts with an existing one, use overwrite param to fix it",
+                                keys,
                             )
 
     def _reload_from_obj(self, obj):
         for field in self.__fields__:
-            if field == '_id':
+            if field == "_id":
                 continue
             value = getattr(obj, field)
             self.__dict__[field] = value
